hello! 반갑습니다! 이 파일은 shii 폴더의 README.md 파일입니다.
```import shii```
```shii.study(text, text, text)```
```shii.study_return_text(text)```
```shii.study_say(text)```
자세한 것은 https://github.com/boranloves/shii 를 참고 하세요.

필터링 기능을 위하여 ©️korcen을 사용하였습니다.